# Globals

utils::globalVariables(c("mu","sigma","param","lambda",
                         "low","high", "n", "y", "p.value",
                         "Effect", "val","Z","group",
                         "estimate", "lower.ci", "upper.ci"))
